package com.solution.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.solution.system.mapper.NodetemplateMapper;
import com.solution.system.domain.Nodetemplate;
import com.solution.system.service.INodetemplateService;

/**
 * 节点模板Service业务层处理
 * 
 * @author ruoyi
 * @date 2026-02-05
 */
@Service
public class NodetemplateServiceImpl implements INodetemplateService 
{
    @Autowired
    private NodetemplateMapper nodetemplateMapper;

    /**
     * 查询节点模板
     * 
     * @param id 节点模板主键
     * @return 节点模板
     */
    @Override
    public Nodetemplate selectNodetemplateById(Long id)
    {
        return nodetemplateMapper.selectNodetemplateById(id);
    }

    /**
     * 查询节点模板列表
     * 
     * @param nodetemplate 节点模板
     * @return 节点模板
     */
    @Override
    public List<Nodetemplate> selectNodetemplateList(Nodetemplate nodetemplate)
    {
        return nodetemplateMapper.selectNodetemplateList(nodetemplate);
    }

    /**
     * 新增节点模板
     * 
     * @param nodetemplate 节点模板
     * @return 结果
     */
    @Override
    public int insertNodetemplate(Nodetemplate nodetemplate)
    {
        return nodetemplateMapper.insertNodetemplate(nodetemplate);
    }

    /**
     * 修改节点模板
     * 
     * @param nodetemplate 节点模板
     * @return 结果
     */
    @Override
    public int updateNodetemplate(Nodetemplate nodetemplate)
    {
        return nodetemplateMapper.updateNodetemplate(nodetemplate);
    }

    /**
     * 批量删除节点模板
     * 
     * @param ids 需要删除的节点模板主键
     * @return 结果
     */
    @Override
    public int deleteNodetemplateByIds(Long[] ids)
    {
        return nodetemplateMapper.deleteNodetemplateByIds(ids);
    }

    /**
     * 删除节点模板信息
     * 
     * @param id 节点模板主键
     * @return 结果
     */
    @Override
    public int deleteNodetemplateById(Long id)
    {
        return nodetemplateMapper.deleteNodetemplateById(id);
    }
}
